@@ -1,5 +1,6 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
 # This package is free software; you can redistribute it and/or modify
@@ -400,6 +401,6 @@ class MapareaPropertiesDialog(wx.Dialog):
 
     node = property(get_node)
 
-__all__ = 'MapareaPropertiesDialog'
+__all__ = ['MapareaPropertiesDialog']
 
 # vim:ts=4 sw=4 et
