@@ -1,5 +1,6 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
 # This package is free software; you can redistribute it and/or modify
@@ -137,6 +138,6 @@ class MetadataDialog(wx.Dialog):
         sizer.Add(button_sizer, 0, wx.EXPAND | wx.ALL, 5)
         self.SetSizerAndFit(sizer)
 
-__all__ = 'MetadataDialog',
+__all__ = ['MetadataDialog']
 
 # vim:ts=4 sw=4 et
