@@ -1,5 +1,6 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
 # This package is free software; you can redistribute it and/or modify
@@ -17,6 +18,7 @@ import djvusmooth.models.outline
 from djvusmooth import models
 from djvusmooth.varietes import replace_control_characters
 from djvusmooth.i18n import _
+from djvusmooth.gui import wxcompat
 
 def get_label_for_node(node):
     return replace_control_characters(' ', node.text)
@@ -49,6 +51,7 @@ class OutlineBrowser(wx.TreeCtrl):
         self.Bind(wx.EVT_TREE_END_LABEL_EDIT, self.on_end_edit, self)
         self.Bind(wx.EVT_TREE_SEL_CHANGED, self.on_selection_changed, self)
         self.Bind(wx.EVT_CHAR, self.on_char)
+        self.Bind(wx.EVT_KEY_DOWN, self.on_key_down)
         self.Bind(wx.EVT_TREE_BEGIN_DRAG, self.on_begin_drag)
         self.Bind(wx.EVT_TREE_END_DRAG, self.on_end_drag)
 
@@ -91,6 +94,8 @@ class OutlineBrowser(wx.TreeCtrl):
         source_node.notify_select()
 
     def do_goto_node(self, node):
+        if isinstance(node, models.outline.RootNode):
+            return
         uri = node.uri
         if uri.startswith('#'):
             try:
@@ -118,6 +123,7 @@ class OutlineBrowser(wx.TreeCtrl):
         try:
             method = self._WXK_TO_METHOD[key_code]
         except KeyError:
+            event.Skip()
             return
         item = self.GetSelection()
         node = self.GetPyData(item)
@@ -125,6 +131,9 @@ class OutlineBrowser(wx.TreeCtrl):
             return
         method(self, node)
 
+    def on_key_down(self, event):
+        return wxcompat.on_key_down(self, event)
+
     def on_node_select(self, node):
         try:
             item = self._items[node]
@@ -257,6 +266,6 @@ class OutlineBrowser(wx.TreeCtrl):
         if self._create_root_item():
             self._add_children(self._root_item, self.document.outline.root)
 
-__all__ = 'OutlineBrowser',
+__all__ = ['OutlineBrowser']
 
 # vim:ts=4 sw=4 et
