@@ -1,5 +1,6 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -327,7 +328,7 @@ class TextShape(NodeShape):
     }
 
     def _get_frame_color(self):
-        return wx.Color(*self._FRAME_COLORS[self._node.type])
+        return wx.Colour(*self._FRAME_COLORS[self._node.type])
 
     def _get_text(self):
         if self._node.is_inner():
@@ -626,7 +627,7 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         if self.GetSize() == size:
             return
         self.SetSize(size)
-        self.SetBestFittingSize(size)
+        self.SetInitialSize(size)
         self.GetParent().Layout()
         self.GetParent().SetupScrolling()
 
@@ -670,10 +671,10 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         except decode.NotAvailable:
             pass
 
-__all__ = (
+__all__ = [
     'Zoom', 'PercentZoom', 'OneToOneZoom', 'StretchZoom', 'FitWidthZoom', 'FitPageZoom',
     'PageWidget',
     'RENDER_NONRASTER_TEXT', 'RENDER_NONRASTER_MAPAREA'
-)
+]
 
 # vim:ts=4 sw=4 et
