@@ -1,5 +1,6 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +37,6 @@ class MultiPageModel(object):
         for id in sorted(self._pages):
             self._pages[id].export(djvused)
 
-__all__ = 'MultiPageModel', 'SHARED_ANNOTATIONS_PAGENO'
+__all__ = ['MultiPageModel', 'SHARED_ANNOTATIONS_PAGENO']
 
 # vim:ts=4 sw=4 et
